@@ -1,8 +1,8 @@
 `plot.specaccum` <-
     function(x, add = FALSE, random = FALSE, ci = 2,
-             ci.type = c("bar","line","polygon"), col = par("fg"), ci.col = col,
-             ci.lty = 1, xlab, ylab = x$method, ylim,
-             xvar = c("sites", "individuals", "effort"), ...)
+             ci.type = c("bar","line","polygon"), col = par("fg"), lty = 1,
+             ci.col = col, ci.lty = 1, ci.length = 0,  xlab, ylab = x$method,
+             ylim, xvar = c("sites", "individuals", "effort"), ...)
 {
     if(random && !(x$method %in% c("random", "collector")))
         stop("random = TRUE can be used only with method='random'")
@@ -34,8 +34,10 @@
     }
     if (!is.null(x$sd) && ci)
         switch(ci.type,
-               bar = segments(xaxvar, x$richness - ci*x$sd, xaxvar,
-                  x$richness + ci*x$sd, col=ci.col, lty=ci.lty, ...),
+               bar = {k <- x$sd > sqrt(.Machine$double.eps)
+                      arrows(xaxvar[k], (x$richness - ci*x$sd)[k], xaxvar[k],
+                             (x$richness + ci*x$sd)[k], col=ci.col, lty=ci.lty,
+                             length = ci.length, angle = 90, code = 3, ...)},
                line = matlines(xaxvar, x$richness + t(rbind(-ci,ci) %*% x$sd),
                  col=ci.col, lty=ci.lty, ...),
                polygon = polygon(c(xaxvar, rev(xaxvar)),
@@ -51,7 +53,7 @@
                 lines(x$weights[,i]*adj, x$perm[,i], col=col, ...)
         }
     } else
-        lines(xaxvar, x$richness,col=col, ...)
+        lines(xaxvar, x$richness, col=col, lty = lty, ...)
     invisible()
 }
 
